@echo off
setlocal enableextensions enabledelayedexpansion

@rem ==================================================================
@rem Header 
@rem
@rem Licensed Materials - Property of IBM Corp.
@rem (C) Copyright IBM Corp. 2004
@rem
@rem All Rights Reserved
@rem US Government Users Restricted Rights - Use, duplication or
@rem disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

    @set SCRIPT_VER=01.03
    @set SCRIPT_DATE=12/08/2004
    @set SCRIPT_SCCS=

@rem ==================================================================
@rem History
@rem
@rem DATE        Ver    Auth         Abstract
@rem ----------  -----  -----------  ----------------------------------
@rem 11/15/2004  00.01  brookh       initial design 
@rem 11/18/2004  01.00  brookh       add "-v" option
@rem 11/26/2004  01.01  brookh       Check server status before stop/start
@rem 11/26/2004  01.02  brookh       .pid file is not reliable immediately after 
@rem                                 start/stop, so only check before first start
@rem 12/08/2004  01.03  brookh       Invalid switch - "/stop," 
@rem                                 (missing "@rem" in 2nd line of prev. comment)

@rem ==================================================================
@rem 
@rem Usage: %WAS_HOME%\bin\deploy_IDSWebApp.bat [-v] [-n] [IDSWebApp.war file]
@rem 
@rem Deploys IDSWebApp.war to WAS, retaining the configuration settings of
@rem the currently deployed IDSWebApp, if any. 
@rem 
@rem 1)  deploy_IDSWebApp.bat must be copied to %WAS_HOME%\bin
@rem 
@rem 2)  There are 3 optional cmd line parameters which may appear in any 
@rem     order: 
@rem     
@rem     -v
@rem        
@rem         "version". If "-v" appears anywhere in the command line, 
@rem         then the version and date strings for the deploy_IDSWebApp 
@rem         script, the currently deployed IDSWebApp.war, and the new 
@rem         IDSWebApp.war will be displayed, but the new IDSWebApp.war 
@rem         will not be deployed. Otherwise, the -n and IDSWebApp.war 
@rem         parameters function as described below.        
@rem     
@rem     -n  (Windows only)
@rem     
@rem         "no prompt" suppresses the "Press any key to continue . . ."
@rem         prompt at end of script. This is on by default so that users
@rem         running the script from Windows Explorer ("Open", "Run",
@rem         Dbl-click, or drag-n-drop) can review the status messages 
@rem         before the console window is closed. 
@rem     
@rem     IDSWebApp.war file
@rem     
@rem         A fully qualified file path to the IDSWebApp.war file to deploy.
@rem         Defaults to "%WAS_HOME%\installableApps\IDSWebApp.war" if not
@rem         specified. 

goto :MAIN

@rem ==================================================================
@rem Clear ERRORLEVEL so || and && operators work correctly...
:ClearErrorLevel
    ( dir %COMPSPEC% 2>&1 ) >NUL
goto :EOF

@rem ==================================================================
@rem Print localized "File not found" error and set ERRORLEVEL
:AssertFileExists
    if not exist %1 (
        echo %1
        dir %1 >NUL
    ) else call :ClearErrorLevel
goto :EOF

@rem ==================================================================
@rem Find last '\' in %1 and return S_PATH'\'S_FILE
:Split_Path
    
    set S_PATH=
    set S_FILE=%1
    
    :Split_Path_LOOP
    for /F "usebackq tokens=1* delims=\" %%a in ('!S_FILE!') do (
        if "%%b"=="" (
            set S_FILE=%%a
        ) else (
            set S_FILE=%%b
            if "!S_PATH!"=="" (
                set S_PATH=%%a
            ) else (
                set S_PATH=!S_PATH!\%%a
            )
            goto :Split_Path_LOOP
        )
    )
    
    @rem echo :Split_Path !S_PATH! !S_FILE!
    
goto :EOF


@rem ==================================================================
@rem Echo cmd and then call it
:EchoCmd
    echo.
    echo %*
    call %*
goto :EOF

@rem ==================================================================
@rem Delete %WAS_HOME%\temp\IDSWebApp.tmp directory 
:DeleteTempDirectory
    if exist "!WAS_TEMP!" rmdir /s /q "!WAS_TEMP!" || goto :EOF
    call :ClearErrorLevel
goto :EOF

@rem ==================================================================
@rem Create empty %WAS_HOME%\temp\IDSWebApp.tmp directory w/ dummy file
:CreateTempDirectory
    call :DeleteTempDirectory || goto :EOF
    mkdir "!WAS_TEMP!" || goto :EOF
    call :ClearErrorLevel
goto :EOF

@rem ==================================================================
@rem Parse command line for optional "-n" and IDSWebApp.war file parameters
:ParseCmdLine

    @rem Auto-detect if we're running from a CMD shell or a GUI
    @rem so we know whether to pause before exiting.
    if exist %CMDCMDLINE% (
        set OPTION_N=TRUE
    ) else (
        set OPTION_N=FALSE
    )

    set setupCmdLine.bat=%~dp0setupCmdLine.bat
    set OPTION_V=FALSE

    @rem any param != "-n" or "-v" is asumed to be the IDSWebApp.war file...
    :ParseCmdLine_NEXT
        shift
        if "%~0"=="" (
            call :ClearErrorLevel
            goto :EOF
        ) 
        if "%~0"=="-n" (
            set OPTION_N=TRUE
        ) else if "%~0"=="-v" (
            set OPTION_V=TRUE
        ) else (
            set IDSWebApp=%~f0
        )
    goto :ParseCmdLine_NEXT
    @rem end loop :ParseCmdLine_NEXT

goto :EOF

@rem ==================================================================
@rem 
:InitGlobalVariables

    set WAS_SERVER=server1
    set WAS_TEMP=!WAS_HOME!\temp\deploy_IDSWebApp.tmp
    set IDSWebAppInfo.xml=WEB-INF\classes\IDSConfig\IDSWebAppInfo\IDSWebAppInfo.xml
    set APP_ROOT=!WAS_HOME!\installedApps\!WAS_NODE!\IDSWebApp.war.ear\IDSWebApp.war
    set CONFIG_FILES=WEB-INF\classes\security\console_passwd WEB-INF\classes\IDSConfig\IDSServersConfig\IDSServersInfo.xml WEB-INF\classes\IDSConfig\IDSAppReg\IDSAppReg.xml WEB-INF\classes\IDSConfig\IDSSessionConfig\IDSSessionMgmt.xml

    @rem if IDSWebApp not passed on cmd line, default to %WAS_HOME%\installableApps
    if "!IDSWebApp!"=="" (
        set IDSWebApp=!WAS_HOME!\installableApps\IDSWebApp.war
    )

goto :EOF

@rem ==================================================================
@rem Copy %1 from APP_ROOT to WAS_TEMP
:Backup_File

    call :Split_Path %1
    set SRC_FILE=!APP_ROOT!\%1
    set DST_PATH=!WAS_TEMP!\!S_PATH!
    if exist "!SRC_FILE!" (
        call :EchoCmd mkdir "!DST_PATH!" || goto :EOF
        call :EchoCmd copy "!SRC_FILE!" "!DST_PATH!" || goto :EOF
    ) else call :ClearErrorLevel

goto :EOF

@rem ==================================================================
@rem Copy %1 from APP_ROOT to WAS_TEMP
:RestoreFile

    set SRC_FILE=!WAS_TEMP!\%1
    set DST_FILE=!APP_ROOT!\%1
    if exist "!SRC_FILE!" (
        call :EchoCmd copy /y "!SRC_FILE!" "!DST_FILE!" || goto :EOF
    ) else call :ClearErrorLevel

goto :EOF

@rem ==================================================================
@rem If IDSWebApp.war is deployed to WAS_NODE of WAS_HOME,
@rem then copy CONFIG_FILES from APP_ROOT to WAS_TEMP
:Backup_IDSWebApp_Configuration

    for %%f in (%CONFIG_FILES%) do (
        call :Backup_File %%f || goto :EOF
    )

goto :EOF

@rem ==================================================================
@rem Restore CONFIG_FILES (if any) from WAS_TEMP to APP_ROOT
:Restore_IDSWebApp_Configuration

    for %%f in (%CONFIG_FILES%) do (
        call :RestoreFile %%f || goto :EOF
    )

goto :EOF

@rem ==================================================================
@rem if WAS is not running, start it
:Start_WAS
    call :EchoCmd "!WAS_HOME!\bin\startServer.bat" !WAS_SERVER!
goto :EOF

@rem ==================================================================
@rem if WAS is running, stop it
:Stop_WAS
    call :EchoCmd "!WAS_HOME!\bin\stopServer.bat" !WAS_SERVER!
goto :EOF

@rem ==================================================================
:Restart_WAS
    call :Stop_WAS
    call :Start_WAS
goto :EOF

@rem ==================================================================
@rem Un-deploy existing IDSWebApp.war (if found)...
:Uninstall_IDSWebApp

    if exist "!APP_ROOT!\WEB-INF\classes\security\console_passwd" (
        call :EchoCmd "!WAS_HOME!\bin\wsadmin.bat" -c "$AdminApp uninstall IDSWebApp.war"
    ) else call :ClearErrorLevel

goto :EOF

@rem ==================================================================
@rem Deploy existing IDSWebApp.war ...
:Install_IDSWebApp

    call :EchoCmd "!WAS_HOME!\bin\wsadmin.bat" -conntype NONE -c "$AdminApp install {!IDSWebApp!} {-configroot \"!CONFIG_ROOT!\" -node !WAS_NODE! -usedefaultbindings -nodeployejb -appname IDSWebApp.war -contextroot \"IDSWebApp\"}"

goto :EOF

@rem ==================================================================
@rem Display app-version and build-date of IDSWebAppInfo.xml file
@rem or localized 'not found' message
:ShowIDSWebAppInfo

    if exist %1 (
        "%WINDIR%\system32\findstr.exe" /L "app-version build-date" %1
    ) else (
        dir %1 >NUL
    )

goto :EOF

@rem ==================================================================
@rem "-v"
:ShowVersionInfo

    @rem Show script version
    echo.
    echo %~f0:
    echo     SCRIPT_VER:  %SCRIPT_VER%
    echo     SCRIPT_DATE: %SCRIPT_DATE%

    @rem Show version of new IDSWebApp
    echo.
    echo !IDSWebApp!:
    if exist "!IDSWebApp!" (
        pushd "!WAS_TEMP!"
        "!JAVA_HOME!\bin\jar.exe" -xf "!IDSWebApp!" !IDSWebAppInfo.xml!
        popd
        if exist "!WAS_TEMP!\!IDSWebAppInfo.xml!" (
            call :ShowIDSWebAppInfo "!WAS_TEMP!\!IDSWebAppInfo.xml!"
        ) else (
            echo     Not a valid IDSWebApp.war file?
        )
    ) else (
        dir "!IDSWebApp!" >NUL
    )

    @rem Show version of installed IDSWebApp
    @rem echo.
    @rem echo !APP_ROOT!:
    @rem call :ShowIDSWebAppInfo "!APP_ROOT!\!IDSWebAppInfo.xml!"

goto :EOF



@rem ==================================================================
:MAIN

    call :ParseCmdLine %*

    @rem call %WAS_HOME%\bin\setupCmdLine.bat
        call :AssertFileExists "!setupCmdLine.bat!" || goto :END
        call "!setupCmdLine.bat!" || goto :END

    @rem Initialize global variables...
        call :InitGlobalVariables
    
    @rem we need a tmp directory...
        call :CreateTempDirectory || goto :END
        call :AssertFileExists "!WAS_TEMP!" || goto :END
        
    @rem if "-v"...
        if "!OPTION_V!"=="TRUE" (
            call :ShowVersionInfo
            goto :SUCCESS
        )
        
    @rem if we're actually going to install the new .war, it must exist
        call :AssertFileExists "!IDSWebApp!" || goto :END

    @rem Backup existing configuration (if found)...
        call :Backup_IDSWebApp_Configuration || goto :END

    @rem WAS must be running...
        if not exist "!WAS_HOME!\logs\!WAS_SERVER!\!WAS_SERVER!.pid" (
            call :Start_WAS || goto :END
        )
        call :ClearErrorLevel
    
    @rem Un-deploy existing IDSWebApp.war (if found)...
        call :Uninstall_IDSWebApp || goto :END

    @rem Deploy new IDSWebApp.war ...
        call :Install_IDSWebApp || goto :END
        
    @rem Restore previous configuration (if any)...
        call :Restore_IDSWebApp_Configuration
        
    @rem Restart WAS
        call :Restart_WAS

:SUCCESS
    call :DeleteTempDirectory
    echo.
    echo "!APP_ROOT!"
    call :ShowIDSWebAppInfo "!APP_ROOT!\!IDSWebAppInfo.xml!"
    
goto :END

@rem ==================================================================
:END
if not "!OPTION_N!"=="TRUE" pause
endlocal
